Lua_MailWindow = class("Lua_MailWindow", Lua_Window);
function Lua_MailWindow:ctor()
    self:superCall("ctor");

    self.windowName = "Lua_MailWindow";
    self.skinName = "MailWindow_skin";
    self.showBlackMask = true;
    self.isClickClose = true;
end

function Lua_MailWindow:buildShowItem()
    self:superCall("buildShowItem");

    self.dragList = Lua_DragList.new(self.content, 645, 632, Lua_AxisDefine.Vertical);
    self.dragList:setListCell(Lua_MailItem, 645, 126, 1);
    self.dragList:setLocation(0, 51, 0);
    self.dragList.tweenId = 2018;

    self.removeBtn:addClickFuntion(self, self.onRemoveBtnClick);
    self.rewardBtn:addClickFuntion(self, self.onAllRewardBtnClick);

    self:updataMailInfo();

    self:addLuaEvent("UPDATA_MAILITEM_ONE", self, self.updataOneItem);
    self:addLuaEvent("UPDATA_MAILITEM_LIST", self, self.updataItemList);
    self:addLuaEvent("REMOVE_MAILITEM", self, self.removeItem);
end

function Lua_MailWindow:onRemoveBtnClick(go)
    if self.mailList:getSize() == 0 or not self.isCanRemove then
        OperateAlert.showLangValue(128000);
        return;
    end
    Lua_ProxyManager.getProxy("Lua_MailProxy"):sRemoveMailItem(DataCenter.mailData:getMailReadAndNoAttachList());
end

function Lua_MailWindow:onAllRewardBtnClick(go)
    if self.mailList:getSize() == 0 or DataCenter.mailData.hasAttach == false then
        OperateAlert.showLangValue(128001);
        return;
    end
    OperateAlert.showLangValue(128002);
    Lua_ProxyManager.getProxy("Lua_MailProxy"):sReceiveMailItem(0);
end

function Lua_MailWindow:updataMailInfo()
    self.mailList = DataCenter.mailData:getMailListAndSort();
    self.dragList:setArrayData(self.mailList);
    self.noneObject:SetActive(self.mailList:getSize() <= 0);

    self.isCanRemove = false;
    for i = 1, self.mailList:getSize() do
        if self.mailList[i].has_read == 1 and self.mailList[i].has_attach == 0 then
            self.isCanRemove = true;
            break;
        end
    end
end

function Lua_MailWindow:updataOneItem(item)
    self:updataMailInfo();
end

function Lua_MailWindow:updataItemList(itemList)
    self:updataMailInfo();
end

function Lua_MailWindow:removeItem(itemList)
    self:updataMailInfo();
    OperateAlert.showLangValue(128003);
end

function Lua_MailWindow:dispose()
    if self.dragList ~= nil then
        self.dragList:dispose();
        self.dragList=nil;
    end

    self:superCall("dispose");
end





--------------------------------------------------





Lua_MailItem = class("Lua_MailItem", Lua_ListCell);
function Lua_MailItem:ctor(p)
    self:superCall("ctor", p, "MailItem_skin");
end
function Lua_MailItem:buildShowItem()
    self:superCall("buildShowItem");
    
    self.itemList = Lua_DragList.new(self.content, 350, 66, Lua_AxisDefine.Horizontal);
    self.itemList:setListCell(Lua_MailItemIconCell, 66, 66, 1);
    self:setSubList(self.itemList);
    self.itemList:setRectPivot(3);
    self.itemList:setLocation(-163, -18);

    self.mailIcon:SetDimensions(0, 0);
end

function Lua_MailItem:setData(data)
    self.data = data;
    if data == nil then
        return;
    end

    self.titleTxt.text = data.title;
    self.timeTxt:setLocation(269, 0);

    if data.item_list ~= nil then
        local arr = Array();
        for i = 1, #data.item_list do
            if #data.item_list > 5 then
                arr:add({itemInfo = data.item_list[i], mailId = data.mail_id, isGray = data.has_attach == 0});
            else
                arr:add({itemInfo = data.item_list[i], isGray = data.has_attach == 0});
            end
        end
        self.itemList:setArrayData(arr);
        self.itemList.canDrag = #data.item_list > 5;

        self.titleTxt:setLocation(-166, 50);
    else
        self.titleTxt:setLocation(-166, 15);
    end

    if data.has_read == 0 then
        self.mailIcon:setAltas("mail_atlas", "ui_yj_icon_02");
        self.mailIcon:resetSize();
        self.mailIcon:setScale(0.7, 0.7, 0.7);
        self.timeTxt:setLangValue(128004); 
    else
        if data.has_attach == 1 then
            self.mailIcon:setAltas("mail_atlas", "ui_yj_icon_01");
            self.mailIcon:resetSize();
            self.mailIcon:setScale(0.7, 0.7, 0.7);
            self.timeTxt:setLangValue(128005);
        else
            self.mailIcon:setAltas("mail_atlas", "ui_yj_icon_03");
            self.mailIcon:resetSize();
            self.timeTxt:setLocation(254, 0);

            local sec = DataCenter.roleData.serverTime - data.send_tick;
            local hour = Mathf.Modf(sec / 3600);
            if hour < 1 then
                if sec < 60 then
                    self.timeTxt.text = LanUtil.formateStr(128007, "1");
                else
                    self.timeTxt.text = LanUtil.formateStr(128007, Mathf.Modf(sec / 60));
                end
            elseif hour < 24 then
                self.timeTxt.text = LanUtil.formateStr(128008, hour);
            else
                self.timeTxt.text = LanUtil.formateStr(128006, Mathf.Modf(sec / 86400));
            end
        end
    end
    
    self:showRedDot(data.has_read == 0 or data.has_attach == 1);
    self.maskSp:setEnable(data.has_read ~= 0 and data.has_attach == 0);
    self.newSp:setEnable(data.has_read == 0);
end

function Lua_MailItem:showRedDot(bShow)
    if bShow == true then
        if self.redPoint == nil then
            self.redPoint = Lua_RedPointIcon.new(self.content);
            self.redPoint:setLocation(303, 49, 0);
            self.redPoint:createRedPointEff();
        end
        self.redPoint:updateRedPointShow(true);
    else
        if self.redPoint ~= nil then
            self.redPoint:updateRedPointShow(false);
        end
    end
end

function Lua_MailItem:onPressClick()
    if self.data == nil then
        return;
    end

    Lua_WindowUtil.openWin("Lua_MailItemInfoWindow", Lua_WinParam.ACTION_OPEN, self.data.mail_id);
end

function Lua_MailItem:dispose()
    if self.redDotEff ~= nil then
        self.redDotEff:dispose();
        self.redDotEff = nil;
    end
    if self.itemList ~= nil then
        self.itemList:dispose();
        self.itemList = nil;
    end
    self.data = nil;

    self:superCall("dispose");
end





Lua_MailItemIconCell = class("Lua_MailItemIconCell", Lua_ListCell)
function Lua_MailItemIconCell:ctor(p)
    self:superCall("ctor", p);
end

function Lua_MailItemIconCell:buildShowItem()
    self:superCall("buildShowItem");
    self.itemIcon = Lua_ItemIcon.new(self.content);
    self.itemIcon:setScale(0.45, 0.45);
end

function Lua_MailItemIconCell:setData(data)
    self.data = data;
    
    if self.itemVo == nil then
        self.itemVo = Lua_ToolVo.createToolVo(data.itemInfo.id);
    else
        self.itemVo:setData(data.itemInfo.id);
    end
    self.itemVo:fromServer(data.itemInfo);
    self.itemIcon:setData(self.itemVo);
    self.itemIcon:setGray(data.isGray);
    self.itemIcon:setCanClick(false);
end

function Lua_MailItemIconCell:onPressClick()
    if self.data.mailId ~= nil then
        Lua_WindowUtil.openWin("Lua_MailItemInfoWindow", Lua_WinParam.ACTION_OPEN, self.data.mailId);
    end
end

function Lua_MailItemIconCell:dispose()
    if self.itemIcon ~= nil then
        self.itemIcon:dispose();
        self.itemIcon = nil;
    end
    self:superCall("dispose");
end